HamugaButtonVariant enum

The visual variant of the HamugaIdButton.

Inheritance
Available extensions

Values

primary → const HamugaButtonVariant

Primary style (blue background, white text).

secondaryGray → const HamugaButtonVariant

Secondary gray style (white background, gray border, gray text).

secondaryColor → const HamugaButtonVariant

Secondary color style (white background, blue border, blue text).

tertiaryGray → const HamugaButtonVariant

Tertiary gray style (transparent background, gray text).

tertiaryColor → const HamugaButtonVariant

Tertiary color style (transparent background, blue text).

linkGray → const HamugaButtonVariant

Gray link style (text only, gray).

linkColor → const HamugaButtonVariant

Color link style (text only, blue).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HamugaButtonVariant>
A constant List of the values in this enum, in order of their declaration.