leadingIcon property
An optional widget to display before the text (e.g., an icon).
Defaults to the Hamuga ID logo.
Implementation
final Widget? leadingIcon;
An optional widget to display before the text (e.g., an icon).
Defaults to the Hamuga ID logo.
final Widget? leadingIcon;