state property
The state parameter for the authentication request.
If not provided, a random state will be generated by HamugaId.signIn.
Implementation
final String? state;
The state parameter for the authentication request.
If not provided, a random state will be generated by HamugaId.signIn.
final String? state;