close method
Closes the in-app browser view.
This can be used to manually close the authentication screen.
Implementation
Future<void> close() async {
_log('Closing browser manually');
await closeInAppWebView();
}
Closes the in-app browser view.
This can be used to manually close the authentication screen.
Future<void> close() async {
_log('Closing browser manually');
await closeInAppWebView();
}