autoClose property
Whether to automatically close the browser when a redirect is matched. Defaults to true.
Implementation
final bool autoClose;
Whether to automatically close the browser when a redirect is matched. Defaults to true.
final bool autoClose;