HamugaIdResponse class

Represents the response from Hamuga ID authentication.

Constructors

HamugaIdResponse({String? code, String? state, String? error, String? errorDescription})
Creates a new HamugaIdResponse instance.
HamugaIdResponse.fromUri(Uri uri)
Creates a HamugaIdResponse from a Uri.
factory

Properties

code String?
The authorization code.
final
error String?
The error code, if an error occurred.
final
errorDescription String?
A description of the error, if an error occurred.
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
Returns true if an error occurred during authentication.
no setter
isSuccess bool
Returns true if the authentication was successful.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The state parameter from the request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited