HamugaIdButton class
A customizable button widget for Hamuga ID authentication.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- HamugaIdButton
Constructors
-
HamugaIdButton({Key? key, VoidCallback? onPressed, String text = 'Хамуга ID-р нэвтрэх', Widget? leadingIcon, Widget? trailingIcon, HamugaButtonSize size = HamugaButtonSize.md, HamugaButtonVariant variant = HamugaButtonVariant.secondaryGray, String? clientId, String? redirectUri, String? state, String? baseUrl, List<
HamugaIdScope> ? scope, String? responseType, bool enabled = true, HamugaIdUsername? username}) -
Creates a HamugaIdButton.
const
Properties
- baseUrl → String?
-
The base URL for the authentication endpoint.
final
- clientId → String?
-
The client ID for authentication.
final
- enabled → bool
-
Whether the button is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leadingIcon → Widget?
-
An optional widget to display before the text (e.g., an icon).
final
- onPressed → VoidCallback?
-
Optional callback to execute after the authentication flow is triggered.
final
- redirectUri → String?
-
The redirect URI for authentication.
final
- responseType → String?
-
The response type for the authentication request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scope
→ List<
HamugaIdScope> ? -
The list of scopes to request.
final
- size → HamugaButtonSize
-
The size of the button.
final
- state → String?
-
The state parameter for the authentication request.
final
- text → String
-
The text to display on the button.
final
- trailingIcon → Widget?
-
An optional widget to display after the text.
final
- username → HamugaIdUsername?
-
The username parameter to pre-fill the login form.
final
- variant → HamugaButtonVariant
-
The visual variant of the button.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited