HamugaIdConfig class
Configuration for Hamuga ID SDK.
Constructors
-
HamugaIdConfig({required String clientId, required String redirectUri, required List<
HamugaIdScope> scopes, String baseUrl = 'https://id.hamuga.mn/auth/login', bool enableLogging = false, bool autoClose = true}) -
Creates a new HamugaIdConfig instance.
const
Properties
- autoClose → bool
-
Whether to automatically close the browser when a redirect is matched.
Defaults to true.
final
- baseUrl → String
-
The base URL for the authentication endpoint.
Defaults to 'https://id.hamuga.mn/auth/login'.
final
- clientId → String
-
Your application's client ID.
final
- enableLogging → bool
-
Whether to enable logging for debugging.
Defaults to false.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirectUri → String
-
The URI to redirect to after authentication.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
HamugaIdScope> -
A list of scopes to request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited